@@ -12,13 +12,15 @@ manifest_commands = {
                 "This is a required argument."
             ),
             "title": (
-                "Specify the title of the manifest that will be created at the end of the run. "
-                "You can either explicitly pass the title of the manifest here or provide it in the `config.yml` "
+                "Specify the title of the manifest (or title prefix of multiple manifests) that "
+                "will be created at the end of the run. You can either explicitly pass the "
+                "title of the manifest here or provide it in the `config.yml` "
                 "file as a value for the `(manifest > title)` key."
             ),
             "data_type": (
-                "Specify the component (data type) from the data model that is to be used "
-                "for generating the metadata manifest file. You can either explicitly pass the data type here or provide "
+                "Specify the component(s) (data type) from the data model that is to be used "
+                "for generating the metadata manifest file. To make all available manifests enter 'all manifests'. "
+                "You can either explicitly pass the data type here or provide "
                 "it in the `config.yml` file as a value for the `(manifest > data_type)` key."
             ),
             "jsonld": (
@@ -34,6 +36,7 @@ manifest_commands = {
                 "to the metadata manifest file. If not it will produce a pandas dataframe for the same."
             ),
             "output_csv": ("Path to where the CSV manifest template should be stored."),
+            "output_xlsx": ("Path to where the Excel manifest template should be stored."),
             "use_annotations": (
                 "This is a boolean flag. If flag is provided when command line utility is executed, it will prepopulate template "
                 "with existing annotations from Synapse."
@@ -47,6 +50,10 @@ manifest_commands = {
                 "You can either explicitly pass the `.json` file here or provide it in the `config.yml` file "
                 "as a value for the `(model > input > validation_schema)` key."
             ),
+            "alphabetize_valid_values": (
+                "Specify to alphabetize valid attribute values either ascending (a) or descending (d)." 
+                "Optional"
+            ),
         },
     }
 }
@@ -72,6 +79,21 @@ model_commands = {
                 "The component or data type from the data model which you can use to validate the "
                 "data filled in your manifest template."
             ),
+            "use_schema_label": (
+                "Store attributes using the schema label (--use_schema_label, default) or store attributes using the display label "
+                "(--use_display_label). Attribute display names in the schema must not only include characters that are "
+                "not accepted by Synapse. Annotation names may only contain: letters, numbers, '_' and '.'"
+            ),
+            "hide_blanks":(
+                "This is a boolean flag. If flag is provided when command line utility is executed, annotations with blank values will be hidden from a dataset's annotation list in Synaspe."
+                "If not, annotations with blank values will be displayed."
+            ),
+            "manifest_record_type":(
+                "Specify the way the manifest should be store as on Synapse. Options are 'entity', 'table' and "
+                "'both'. 'entity' will store the manifest as a csv and create Synapse files for each row in the manifest. "
+                "'table' will store the manifest as a table and a csv on Synapse. 'both' will do both of the options specified above. "
+                "Default value is 'table'."
+            ),      
         },
         "validate": {
             "short_help": ("Validation of manifest files."),
@@ -89,6 +111,14 @@ model_commands = {
                 "You can either explicitly pass the `.json` file here or provide it in the `config.yml` file "
                 "as a value for the `(model > input > validation_schema)` key."
             ),
+            "restrict_rules":(
+                "This is a boolean flag. If flag is provided when command line utility is executed, validation suite will only run with in-house validation rules, "
+                "and Great Expectations rules and suite will not be utilized."
+                "If not, the Great Expectations suite will be utilized and all rules will be available."
+            ),
+            "project_scope": (
+                "Specify a comma-separated list of projects to search through for cross manifest validation."
+            ),
         },
     }
 }
