@@ -1,5 +1,6 @@
 #!/usr/bin/env python3
 
+from gc import callbacks
 import logging
 import sys
 
@@ -9,7 +10,7 @@ import click_log
 from jsonschema import ValidationError
 
 from schematic.models.metadata import MetadataModel
-from schematic.utils.cli_utils import get_from_config, fill_in_from_config, query_dict
+from schematic.utils.cli_utils import get_from_config, fill_in_from_config, query_dict, parse_synIDs, parse_comma_str_to_list
 from schematic.help import model_commands
 from schematic.exceptions import MissingConfigValueError
 from schematic import CONFIG
@@ -63,11 +64,45 @@ def model(ctx, config):  # use as `schematic model ...`
     "--validate_component",
     help=query_dict(model_commands, ("model", "submit", "validate_component")),
 )
+@click.option(
+    "--use_schema_label/--use_display_label",
+    "-sl/-dl",
+    default=True,
+    help=query_dict(model_commands, ("model", "submit", "use_schema_label")),
+)
+@click.option(
+    "--hide_blanks",
+    "-hb",
+    is_flag=True,
+    help=query_dict(model_commands,("model","submit","hide_blanks")),
+)
+@click.option(
+    "--manifest_record_type",
+    "-mrt",
+    default='both',
+    type=click.Choice(['table', 'entity', 'both'], case_sensitive=True),
+    help=query_dict(model_commands, ("model", "submit", "manifest_record_type")))
+@click.option(
+    "-rr",
+    "--restrict_rules",
+    is_flag=True,
+    help=query_dict(model_commands,("model","validate","restrict_rules")),
+)
+@click.option(
+    "-ps",
+    "--project_scope",
+    default=None,
+    callback=parse_synIDs,
+    help=query_dict(model_commands, ("model", "validate", "project_scope")),
+)
 @click.pass_obj
-def submit_manifest(ctx, manifest_path, dataset_id, validate_component):
+def submit_manifest(
+    ctx, manifest_path, dataset_id, validate_component, manifest_record_type, use_schema_label, hide_blanks, restrict_rules, project_scope,
+):
     """
     Running CLI with manifest validation (optional) and submission options.
     """
+
     jsonld = get_from_config(CONFIG.DATA, ("model", "input", "location"))
 
     model_file_type = get_from_config(CONFIG.DATA, ("model", "input", "file_type"))
@@ -77,13 +112,29 @@ def submit_manifest(ctx, manifest_path, dataset_id, validate_component):
     )
 
     try:
-        success = metadata_model.submit_metadata_manifest(
+        manifest_id = metadata_model.submit_metadata_manifest(
+            path_to_json_ld = jsonld,
             manifest_path=manifest_path,
             dataset_id=dataset_id,
             validate_component=validate_component,
+            manifest_record_type=manifest_record_type,
+            restrict_rules=restrict_rules,
+            use_schema_label=use_schema_label,
+            hide_blanks=hide_blanks,
+            project_scope=project_scope,
         )
 
-        if success:
+        '''
+        if censored_manifest_id:
+            logger.info(
+                f"File at '{manifest_path}' was censored and successfully associated "
+                f"with dataset '{dataset_id}'. "
+                f"An uncensored version has also been associated with dataset '{dataset_id}' "
+                f"and submitted to the Synapse Access Control Team to begin the process "
+                f"of adding terms of use or review board approval."
+            )
+        '''
+        if manifest_id:
             logger.info(
                 f"File at '{manifest_path}' was successfully associated "
                 f"with dataset '{dataset_id}'."
@@ -96,6 +147,10 @@ def submit_manifest(ctx, manifest_path, dataset_id, validate_component):
         logger.error(
             f"Validation errors resulted while validating with '{validate_component}'."
         )
+    except AttributeError:
+        logger.error(
+            f"'{dataset_id}' is not in the asset view (or file view for Synapse user)"
+        )
 
 
 # prototype based on validateModelManifest()
@@ -114,6 +169,7 @@ def submit_manifest(ctx, manifest_path, dataset_id, validate_component):
 @click.option(
     "-dt",
     "--data_type",
+    callback=parse_comma_str_to_list,
     help=query_dict(model_commands, ("model", "validate", "data_type")),
 )
 @click.option(
@@ -121,12 +177,34 @@ def submit_manifest(ctx, manifest_path, dataset_id, validate_component):
     "--json_schema",
     help=query_dict(model_commands, ("model", "validate", "json_schema")),
 )
+@click.option(
+    "-rr",
+    "--restrict_rules",
+    is_flag=True,
+    help=query_dict(model_commands,("model","validate","restrict_rules")),
+)
+@click.option(
+    "-ps",
+    "--project_scope",
+    default=None,
+    callback=parse_synIDs,
+    help=query_dict(model_commands, ("model", "validate", "project_scope")),
+)
 @click.pass_obj
-def validate_manifest(ctx, manifest_path, data_type, json_schema):
+def validate_manifest(ctx, manifest_path, data_type, json_schema, restrict_rules,project_scope):
     """
     Running CLI for manifest validation.
     """
     data_type = fill_in_from_config("data_type", data_type, ("manifest", "data_type"))
+    
+    try:
+        len(data_type) == 1
+    except:
+        logger.error(
+            f"Can only validate a single data_type at a time. Please provide a single data_type"
+        )
+
+    data_type = data_type[0]
 
     json_schema = fill_in_from_config(
         "json_schema",
@@ -134,7 +212,7 @@ def validate_manifest(ctx, manifest_path, data_type, json_schema):
         ("model", "input", "validation_schema"),
         allow_none=True,
     )
-
+    
     jsonld = get_from_config(CONFIG.DATA, ("model", "input", "location"))
 
     model_file_type = get_from_config(CONFIG.DATA, ("model", "input", "file_type"))
@@ -143,8 +221,8 @@ def validate_manifest(ctx, manifest_path, data_type, json_schema):
         inputMModelLocation=jsonld, inputMModelLocationType=model_file_type
     )
 
-    errors = metadata_model.validateModelManifest(
-        manifestPath=manifest_path, rootNode=data_type, jsonSchema=json_schema
+    errors, warnings = metadata_model.validateModelManifest(
+        manifestPath=manifest_path, rootNode=data_type, jsonSchema=json_schema, restrict_rules=restrict_rules, project_scope=project_scope,
     )
 
     if not errors:
