@@ -1,9 +1,9 @@
 # allows specifying explicit variable types
 from typing import Any, Dict, Optional, Text
 
+
 def find_duplicates(_list):
-    """Find duplicate items in a list
-    """
+    """Find duplicate items in a list"""
     return set([x for x in _list if _list.count(x) > 1])
 
 
@@ -25,4 +25,4 @@ def unlist(_list):
     if len(_list) == 1:
         return _list[0]
     else:
-        return _list
\ No newline at end of file
+        return _list
